@@ -28,8 +28,6 @@
 
 #include "config.h"
 
-#include <gtk/gtk.h>
-
 #include <libgimp/gimp.h>
 
 #include <ft2build.h>
@@ -502,11 +500,8 @@ render_string (GimpDrawable *drawable,
 static void
 prepare_text (const gchar* string)
 {
-  Glyph    *glyph;
-  FT_UInt   glyph_index;
-  GdkWChar *wcs;
-  GdkWChar *wcp;
-  gint      wclen;
+  Glyph       *glyph;
+  const gchar *p;
 
   num_glyphs = 0;
 
@@ -515,19 +510,12 @@ prepare_text (const gchar* string)
 
   g_return_if_fail (face != NULL);
 
-  wcs   = g_new (GdkWChar, strlen (string) + 1);
-  wclen = gdk_mbstowcs (wcs, string, strlen (string));
-  wcs[wclen] = 0;
-
-  for (wcp = wcs, glyph = glyphs;
-       *wcp && num_glyphs < MAX_NUM_GLYPHS;
-       wcp++, num_glyphs++, glyph++)
+  for (p = string, glyph = glyphs;
+       *p && num_glyphs < MAX_NUM_GLYPHS;
+       p = g_utf8_next_char (p), glyph++, num_glyphs++)
     {
-      glyph_index = FT_Get_Char_Index (face, (FT_ULong) *wcp);
-      glyph->index = glyph_index;
+      glyph->index = FT_Get_Char_Index (face, (FT_ULong) g_utf8_get_char (p));
     }
-
-  g_free (wcs);
 }
 
 
@@ -803,8 +791,3 @@ free_glyphs (void)
       glyph->image = NULL;
     }
 }
-
-
-
-
-
